@@ -13,9 +13,9 @@ class ExpressError(WSGIHTTPException):
     # code = 200
     # title = 'OK'
     # explanation = 'why this happens'
-    code = None
-    title = "Unknown Error!"
-    explanation = ''
+    code = 500
+    title = U"Unknown Error!"
+    explanation = U''
 
     ## Set this to True for responses that should have no request body
     empty_body = False
